==> ginkgo-hpc-docs-1.7.0-5-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_7.js <==
var searchData=
[
  ['has_5fwith_5fcriteria_0',['has_with_criteria',['../structgko_1_1solver_1_1has__with__criteria.html',1,'gko::solver']]],
  ['has_5fwith_5fcriteria_3c_20solvertype_2c_20xstd_3a_3avoid_5ft_3c_20decltype_28solvertype_3a_3abuild_28_29_2ewith_5fcriteria_28std_3a_3ashared_5fptr_3c_20const_20stop_3a_3acriterionfactory_20_3e_28_29_29_29_3e_20_3e_1',['has_with_criteria&lt; SolverType, xstd::void_t&lt; decltype(SolverType::build().with_criteria(std::shared_ptr&lt; const stop::CriterionFactory &gt;()))&gt; &gt;',['../structgko_1_1solver_1_1has__with__criteria_3_01SolverType_00_01xstd_1_1void__t_3_01decltype_07Sof67c73d1a2e78f628608606c7b5ff68b.html',1,'gko::solver']]],
  ['hip_5fstream_2',['hip_stream',['../classgko_1_1hip__stream.html',1,'gko']]],
  ['hipallocator_3',['HipAllocator',['../classgko_1_1HipAllocator.html',1,'gko']]],
  ['hipallocatorbase_4',['HipAllocatorBase',['../classgko_1_1HipAllocatorBase.html',1,'gko']]],
  ['hipasyncallocator_5',['HipAsyncAllocator',['../classgko_1_1HipAsyncAllocator.html',1,'gko']]],
  ['hipblaserror_6',['HipblasError',['../classgko_1_1HipblasError.html',1,'gko']]],
  ['hiperror_7',['HipError',['../classgko_1_1HipError.html',1,'gko']]],
  ['hipexecutor_8',['HipExecutor',['../classgko_1_1HipExecutor.html',1,'gko']]],
  ['hipffterror_9',['HipfftError',['../classgko_1_1HipfftError.html',1,'gko']]],
  ['hiphostallocator_10',['HipHostAllocator',['../classgko_1_1HipHostAllocator.html',1,'gko']]],
  ['hipranderror_11',['HiprandError',['../classgko_1_1HiprandError.html',1,'gko']]],
  ['hipsparseerror_12',['HipsparseError',['../classgko_1_1HipsparseError.html',1,'gko']]],
  ['hiptimer_13',['HipTimer',['../classgko_1_1HipTimer.html',1,'gko']]],
  ['hipunifiedallocator_14',['HipUnifiedAllocator',['../classgko_1_1HipUnifiedAllocator.html',1,'gko']]],
  ['hwloc_5fobj_5ft_15',['hwloc_obj_t',['../structhwloc__obj__t.html',1,'']]],
  ['hwloc_5fobj_5ftype_5ft_16',['hwloc_obj_type_t',['../structhwloc__obj__type__t.html',1,'']]],
  ['hybrid_17',['Hybrid',['../classgko_1_1matrix_1_1Hybrid.html',1,'gko::matrix']]]
];

==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_7.js <==
var searchData=
[
  ['half_0',['half',['../classgko_1_1half.html',1,'gko']]],
  ['has_5fwith_5fcriteria_1',['has_with_criteria',['../structgko_1_1solver_1_1has__with__criteria.html',1,'gko::solver']]],
  ['hip_5fstream_2',['hip_stream',['../classgko_1_1hip__stream.html',1,'gko']]],
  ['hipallocator_3',['HipAllocator',['../classgko_1_1HipAllocator.html',1,'gko']]],
  ['hipallocatorbase_4',['HipAllocatorBase',['../classgko_1_1HipAllocatorBase.html',1,'gko']]],
  ['hipasyncallocator_5',['HipAsyncAllocator',['../classgko_1_1HipAsyncAllocator.html',1,'gko']]],
  ['hipblaserror_6',['HipblasError',['../classgko_1_1HipblasError.html',1,'gko']]],
  ['hiperror_7',['HipError',['../classgko_1_1HipError.html',1,'gko']]],
  ['hipexecutor_8',['HipExecutor',['../classgko_1_1HipExecutor.html',1,'gko']]],
  ['hipffterror_9',['HipfftError',['../classgko_1_1HipfftError.html',1,'gko']]],
  ['hiphostallocator_10',['HipHostAllocator',['../classgko_1_1HipHostAllocator.html',1,'gko']]],
  ['hipranderror_11',['HiprandError',['../classgko_1_1HiprandError.html',1,'gko']]],
  ['hipsparseerror_12',['HipsparseError',['../classgko_1_1HipsparseError.html',1,'gko']]],
  ['hiptimer_13',['HipTimer',['../classgko_1_1HipTimer.html',1,'gko']]],
  ['hipunifiedallocator_14',['HipUnifiedAllocator',['../classgko_1_1HipUnifiedAllocator.html',1,'gko']]],
  ['hwloc_5fobj_5ft_15',['hwloc_obj_t',['../structhwloc__obj__t.html',1,'']]],
  ['hwloc_5fobj_5ftype_5ft_16',['hwloc_obj_type_t',['../structhwloc__obj__type__t.html',1,'']]],
  ['hybrid_17',['Hybrid',['../classgko_1_1matrix_1_1Hybrid.html',1,'gko::matrix']]]
];
